This folder will contain the files that are part of the development process
but are not meant to be deployed to productions, for instance: Adobe
Photoshop sources, compilers, profilers, notes.
These files will not be copied to the server during the normal deployment cycle.